@@ -10,6 +10,7 @@
 import os, copy, uuid, sys
 import logging
 import numpy as np
+import traceback
 
 # AutonML imports
 import autonml.util as util
@@ -341,7 +342,8 @@ class auto_solutions(object):
             if self.basic_sol.splitter_present() == False or complex_types_present(self.types_present) == True:
                 try:
                     self.basic_sol.run_basic_solution(inputs=[dataset], output_step = output_step_index)
-                except:
+                except Exception as e:
+                    print(e)
                     logging.error(sys.exc_info()[0])
                     self.basic_sol = None
                   
@@ -349,7 +351,8 @@ class auto_solutions(object):
             if self.addn_sol is not None and (self.addn_sol.splitter_present() == False or 'IMAGE' in self.types_present):
                 try:
                     self.addn_sol.run_basic_solution(inputs=[dataset], output_step = output_step_index)
-                except:
+                except Exception as e:
+                    print(e)
                     logging.error(sys.exc_info()[0])
                     self.addn_sol = None
 
@@ -500,7 +503,8 @@ class auto_solutions(object):
                 basic_sol.run_basic_solution(inputs=[dataset], output_step=outputstep, dataframe_step=basic_sol.index_denormalize + 1)
                 total_cols = basic_sol.get_total_cols()
                 logging.info("Total cols = %s", total_cols)
-            except:
+            except Exception as e:
+                print(e)
                 logging.error(sys.exc_info()[0])
                 basic_sol = None
         else:
@@ -569,7 +573,8 @@ class auto_solutions(object):
                 basic_sol.run_basic_solution(inputs=[dataset], output_step=outputstep, dataframe_step=basic_sol.index_denormalize + 1)
                 total_cols = basic_sol.get_total_cols()
                 logging.info("Total cols = %s", total_cols)
-            except:
+            except Exception as e:
+                print(e)
                 logging.error(sys.exc_info()[0])
                 basic_sol = None
 
